function [ret,x0,str,ts,xts]=regboux2(t,x,u,flag);
%REGBOUX2	is the M-file description of the SIMULINK system named REGBOUX2.
%	The block-diagram can be displayed by typing: REGBOUX2.
%
%	SYS=REGBOUX2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGBOUX2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGBOUX2 with a FLAG of zero:
%	[SIZES]=REGBOUX2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[-32000,-32000,-31840,-31975])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']],...
		'position',[653,50,658,55])

add_block('built-in/Note',[sys,'/','TECHNIQUE DE M LAURENS'])
set_param([sys,'/','TECHNIQUE DE M LAURENS'],...
		'position',[620,125,625,130])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[375,530,380,535])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,413,345,517])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[525,300,530,305])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[520,440,525,445])


%     Subsystem  'F(X,t) pour la rotation'.

new_system([sys,'/','F(X,t) pour la rotation'])
set_param([sys,'/','F(X,t) pour la rotation'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/pqr'])
set_param([sys,'/','F(X,t) pour la rotation/pqr'],...
		'position',[325,375,330,380])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Demux'],...
		'outputs','[3 4]',...
		'position',[225,375,275,495])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/tau',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/tau',13,'']],...
		'position',[85,240,90,245])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[105,335,110,340])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Inport'])
set_param([sys,'/','F(X,t) pour la rotation/Inport'],...
		'position',[75,300,95,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression de',13,'toutes les',13,'perturbations']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression de',13,'toutes les',13,'perturbations']],...
		'position',[515,325,520,330])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']])
set_param([sys,'/',['F(X,t) pour la rotation/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['F(X,t) pour la rotation/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']],...
		'position',[630,40,635,45])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/Gain3'],...
		'hide name',0,...
		'position',[885,248,925,282])

add_block('built-in/State-Space',[sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['F(X,t) pour la rotation/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[745,242,845,288])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/out_1'],...
		'position',[1125,325,1145,345])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Gain1'],...
		'hide name',0,...
		'position',[1070,322,1095,348])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Sum1'],...
		'position',[970,194,1010,476])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/magneto.m1'])
set_param([sys,'/','F(X,t) pour la rotation/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[610,379,735,431])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Suppression de',13,'tous les couples']])
set_param([sys,'/',['F(X,t) pour la rotation/Suppression de',13,'tous les couples']],...
		'position',[900,205,905,210])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain'])
set_param([sys,'/','F(X,t) pour la rotation/Gain'],...
		'hide name',0,...
		'position',[460,293,500,327])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Sum2'])
set_param([sys,'/','F(X,t) pour la rotation/Sum2'],...
		'hide name',0,...
		'position',[680,128,720,372])


%     Subsystem  'F(X,t) pour la rotation/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5'],'Location',[298,510,1135,815])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem5/To Workspace2'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[205,38,295,52])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Subsystem5/Demux'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Demux'],...
		'outputs','3',...
		'position',[140,39,180,71])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/in_1'],...
		'position',[65,100,85,120])


%     Subsystem  'F(X,t) pour la rotation/Subsystem5/Subsystem5'.

new_system([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','valeur_creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])

add_block('built-in/Clock',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/Product',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/Product'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_creneau',...
		'buffer','points_trace',...
		'position',[125,193,220,207])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[205,130;205,185;240,185])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],[85,130;85,195;120,200])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'F(X,t) pour la rotation/Subsystem5/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Subsystem5/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','F(X,t) pour la rotation/Subsystem5/Sum1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Subsystem5/Gain1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem5/To Workspace3'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[580,23,675,37])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Subsystem5/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5/Demux1'],...
		'outputs','3',...
		'position',[505,24,545,56])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[105,110;105,55;135,55])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[185,45;200,45])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[550,150;630,150])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[320,110;335,110])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[370,190;520,190])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[480,110;520,110])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[90,110;185,110])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[550,30;575,30])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem5'],[480,110;480,40;500,40])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'F(X,t) pour la rotation/Subsystem5'.

set_param([sys,'/','F(X,t) pour la rotation/Subsystem5'],...
		'hide name',0,...
		'position',[560,166,645,214])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Gain2'])
set_param([sys,'/','F(X,t) pour la rotation/Gain2'],...
		'position',[485,175,530,205])


%     Subsystem  'F(X,t) pour la rotation/Calcul des commandes, moments et roue'.

new_system([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Size',18)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'position',[595,10,600,15])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'Font Size',14,...
		'position',[605,82,610,87])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/pqrQ'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/pqrQ'],...
		'position',[445,205,450,210])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/in_1'],...
		'hide name',0,...
		'position',[430,240,450,260])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/out_5'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/out_5'],...
		'hide name',0,...
		'position',[750,215,770,235])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Pulse crneau']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Pulse crneau']],...
		'position',[285,60,290,65])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],'Location',[153,299,1104,711])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']],...
		'ForeGround',1)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']],...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']],...
		'Font Size',18)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Pour mettre le stop hors course, fixer les gains  0']],...
		'position',[375,370,380,375])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace17']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace17']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace17']],...
		'mat-name','norm_PB_moins_B',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace17']],...
		'position',[395,137,530,163])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace16']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace16']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace16']],...
		'mat-name','PB_moins_B',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace16']],...
		'position',[235,181,330,209])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PB-B']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PB-B']],...
		'ForeGround',1,...
		'BackGround',0,...
		'MATLAB Fcn','PBmoinsB(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PB-B']],...
		'Output Width','3',...
		'position',[135,178,195,212])

add_block('built-in/Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn']],...
		'ForeGround',1,...
		'BackGround',0,...
		'Expr','(u(1)^2+u(2)^2+u(3)^2)^0.5')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn']],...
		'position',[240,140,280,160])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[370,201,400,259])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant2']],...
		'ForeGround',1,...
		'BackGround',0,...
		'Value','3e-7')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant2']],...
		'position',[285,232,335,258])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Gain3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'position',[435,220,475,240])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Gain2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Gain2']],...
		'ForeGround',1,...
		'BackGround',0,...
		'position',[430,273,475,297])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PBplusB']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PBplusB']],...
		'ForeGround',1,...
		'BackGround',0,...
		'MATLAB Fcn','PBplusB(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/PBplusB']],...
		'Output Width','3',...
		'position',[140,58,200,92])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/in_2']],...
		'Port','2',...
		'position',[30,275,50,295])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace21']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace21']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace21']],...
		'mat-name','norm_PB_plus_B',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace21']],...
		'position',[410,17,545,43])

add_block('built-in/Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn1']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Fcn1']],...
		'Expr','(u(1)^2+u(2)^2+u(3)^2)^0.5',...
		'position',[300,20,340,40])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace18']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace18']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace18']],...
		'mat-name','test1',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace18']],...
		'position',[505,170,550,200])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Sum2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Sum2']],...
		'hide name',0,...
		'position',[515,202,540,313])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace19']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace19']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace19']],...
		'mat-name','test2',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace19']],...
		'position',[515,320,560,350])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator1']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Relational',13,'Operator1']],...
		'position',[615,246,645,304])

add_block('built-in/Stop Simulation',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Stop Simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Stop Simulation']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Stop Simulation']],...
		'position',[705,258,745,292])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'Value','5')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/Constant3']],...
		'position',[545,277,595,303])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/in_1']],...
		'position',[35,105,55,125])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/fonction ',13,'d''arrt']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/fonction ',13,'d''arrt']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/fonction ',13,'d''arrt']],...
		'position',[190,268,250,302])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace22']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace22']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace22']],...
		'mat-name','test3',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace22']],...
		'position',[695,215,740,245])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace20']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace20']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace20']],...
		'mat-name','PB_plus_B',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop/To Workspace20']],...
		'position',[255,61,350,89])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[480,230;510,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[405,230;430,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[285,150;390,150])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[340,150;340,215;365,215])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[340,245;365,245])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[255,285;425,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[480,285;510,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[200,195;230,195])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[215,195;215,150;235,150])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[60,115;60,195;130,195])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[55,285;185,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[490,230;500,185])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[495,285;495,335;510,335])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[60,115;60,75;135,75])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[205,75;250,75])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[345,30;405,30])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[235,75;235,30;295,30])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[545,260;610,260])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[650,275;700,275])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[600,290;610,290])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],[670,275;670,230;690,230])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],...
		'Mask Display','STOP MULTIPLE\nVitesses limites\nConvergence boussole')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop']],...
		'ForeGround',1,...
		'BackGround',0,...
		'position',[415,456,580,534])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Champ rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Champ rel']],...
		'position',[865,400,870,405])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Puls',13,'linaire']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Puls',13,'linaire']],...
		'position',[450,90,455,95])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace15']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace15']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','B_prime')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace15']],...
		'buffer','points_trace',...
		'position',[350,34,415,56])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc '].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']],'Location',[4,566,324,746])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /MATLAB Fcn3']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /MATLAB Fcn3']],...
		'position',[105,75,280,125])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /Clock']],...
		'position',[35,84,70,116])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /BX BY BZ']],...
		'position',[195,50,200,55])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc /out_1']],...
		'position',[310,90,330,110])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']],[75,100;100,100])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']],[285,100;305,100])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']],...
		'Mask Display','CALCUL\nBc')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc '].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc ']],...
		'position',[340,187,400,223])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace14']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace14']],...
		'hide name',0,...
		'mat-name','cpl_roue_brut')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace14']],...
		'buffer','points_trace',...
		'position',[795,364,905,386])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain1']],...
		'hide name',0,...
		'position',[680,362,705,388])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux4']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux4']],...
		'position',[1010,37,1050,113])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace13']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace13']],...
		'hide name',0,...
		'mat-name','cpl_roue',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace13']],...
		'position',[1050,629,1120,651])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace4']],...
		'hide name',0,...
		'mat-name','Bc',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace4']],...
		'position',[435,279,500,301])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace5']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','Bc_prime')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace5']],...
		'buffer','points_trace',...
		'position',[430,249,495,271])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[145,180,150,185])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/in_1']],...
		'position',[15,99,30,121])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux3']],...
		'inputs','[3 7]',...
		'position',[280,164,315,246])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B''']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B''']],...
		'position',[450,60,455,65])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Derivative']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Derivative']],...
		'position',[460,209,505,231])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B''c']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B''c']],...
		'position',[520,190,525,195])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B']],...
		'position',[265,155,270,160])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B ']],...
		'position',[510,105,515,110])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Bc']],...
		'position',[490,150,495,155])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],'Location',[442,254,1087,515])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/in_1']],...
		'hide name',0,...
		'position',[25,100,45,120])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_3']],...
		'hide name',0,...
		'Port','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_3']],...
		'position',[360,130,380,150])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_2']],...
		'hide name',0,...
		'position',[360,70,380,90])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_1']],...
		'hide name',0,...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/out_1']],...
		'position',[360,100,380,120])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],'Location',[4,192,1154,487])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']],...
		'Port','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']],...
		'position',[760,185,780,205])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']],...
		'position',[760,145,780,165])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']],...
		'position',[760,105,780,125])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],'Location',[154,322,1099,787])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']],...
		'position',[115,190,135,210])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']],...
		'position',[690,55,695,60])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']],...
		'position',[790,425,795,430])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']],...
		'position',[800,390,820,410])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']],...
		'Port','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']],...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']],...
		'position',[790,145,810,165])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']],...
		'position',[640,134,665,321])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']],...
		'position',[95,250,115,270])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'Value','instant_injection')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'position',[460,206,465,211])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'position',[155,236,295,284])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'mat-name','der_seconde')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'position',[705,568,825,602])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/To File',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'Matrix name','derb_chapeau')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'position',[635,134,730,166])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'MATLAB Fcn','storderB(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'position',[515,208,575,242])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'mat-name','derb_chapeau')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'position',[630,268,750,302])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'Value','Ta/2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'position',[325,189,360,211])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'position',[375,168,400,292])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']],...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'position',[420,45,425,50])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[120,260;150,260])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[300,260;370,260])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'position',[310,260,445,340])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']],...
		'position',[410,385,415,390])

add_block('built-in/Product',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']],...
		'position',[535,227,560,323])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],'Location',[198,215,1097,749])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']],...
		'position',[615,220,635,240])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']],...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']],...
		'position',[445,211,475,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'MATLAB Fcn','storcham(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'position',[505,213,565,247])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']],...
		'Port','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']],...
		'position',[615,420,635,440])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'position',[610,272,660,288])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'position',[375,258,400,382])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'Value','Ta/2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'position',[305,279,340,301])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],'Location',[163,376,803,621])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']],...
		'position',[555,105,575,125])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Size',12)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[135,100,140,105])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'Output Width','1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'inputs','+-')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'Value','instant_injection')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'position',[460,206,465,211])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[500,115;550,115])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'position',[115,326,255,374])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']],...
		'position',[45,330,85,370])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'buffer','20000')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'position',[140,412,190,428])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[390,220;390,110;610,110])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[285,350;370,350])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'position',[300,165,435,235])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']],...
		'position',[495,270,500,275])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']],...
		'position',[535,335,540,340])

add_block('built-in/Derivative',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']],...
		'position',[500,225,505,230])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']],...
		'position',[130,285,135,290])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']],...
		'Port','2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']],...
		'position',[110,310,130,330])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']],...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']],...
		'position',[505,94,545,126])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']],...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']],...
		'position',[680,349,720,381])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'mat-name','b_reel_roulis')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'position',[580,84,660,116])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'mat-name','derb_pulse_roulis')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'position',[755,339,870,371])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'mat-name','champ_pulse')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'position',[745,213,865,247])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']],...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']],...
		'position',[750,279,790,311])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']],...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']],...
		'position',[375,419,415,451])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'mat-name','derb_reel_roulis')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'position',[460,409,540,441])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'mat-name','b_pulse_roulis')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'position',[825,266,925,304])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[670,230;740,230])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[685,230;685,155;785,155])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[450,300;530,300])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[475,300;475,400;795,400])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,175;465,175;465,55;775,55])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[135,320;305,320])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;305,280])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[565,275;635,275])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,225;455,225;455,250;530,250])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,200;580,200;580,180;635,180])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[140,200;295,200])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[275,200;190,200;190,280;225,280])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[465,110;500,110])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[615,400;615,365;675,365])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[550,100;575,100])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[725,355;750,355])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[795,285;820,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[710,230;710,295;745,295])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[420,425;455,425])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;290,435;370,435])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'position',[595,97,730,213])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']],...
		'position',[930,100,935,105])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']],...
		'position',[870,185,875,190])


%     Subsystem  ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'MATLAB Fcn','champmgn(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[240,88,440,162])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']],...
		'position',[160,115,180,135])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']],...
		'position',[150,168,190,202])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[195,185;590,185])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,115;755,115])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,155;755,155])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,195;755,195])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[185,125;235,125])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[445,125;590,125])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES + CHAMP REEL')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'position',[85,64,285,156])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']],...
		'position',[460,65,465,70])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']],...
		'position',[455,95,460,100])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Champ rel']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES/Champ rel']],...
		'position',[425,125,430,130])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],[290,80;355,80])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],[290,110;355,110])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],[290,140;355,140])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],[50,110;80,110])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/CHAMP ET DERIVEE',13,' PULSES']],...
		'position',[85,73,225,147])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux4']],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[1020,196,1045,289])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple ',13,'magntique']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple ',13,'magntique']],...
		'ForeGround',1,...
		'BackGround',2)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple ',13,'magntique']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple ',13,'magntique']],...
		'position',[1070,228,1130,262])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum3']],...
		'hide name',0,...
		'position',[1150,205,1180,365])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux2']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'outputs','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux2']],...
		'position',[605,337,645,413])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple',13,'de commande',13,' raliser']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple',13,'de commande',13,' raliser']],...
		'position',[1230,320,1235,325])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace10']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace10']],...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace10']],...
		'position',[1115,39,1150,61])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace11']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace11']],...
		'hide name',0,...
		'mat-name','my',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace11']],...
		'position',[1115,64,1150,86])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace12']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace12']],...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace12']],...
		'position',[1115,89,1150,111])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue',13,'dimension 3',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue',13,'dimension 3',13,'']],...
		'position',[1150,510,1155,515])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue',13,'uniaxial']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue',13,'uniaxial']],...
		'position',[1120,590,1125,595])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux1']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'outputs','[3 3]')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux1']],...
		'position',[500,320,540,395])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Couple roue']],...
		'position',[760,380,765,385])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace9']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace9']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','cpl_laurens2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace9']],...
		'buffer','points_trace',...
		'position',[1035,134,1155,156])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux2']],...
		'hide name',0,...
		'inputs','3',...
		'position',[1055,450,1085,560])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant1']],...
		'hide name',0,...
		'Value','0',...
		'position',[1000,530,1020,550])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant']],...
		'hide name',0,...
		'Value','0',...
		'position',[1005,460,1025,480])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/out_2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/out_2']],...
		'Port','2',...
		'position',[1210,580,1230,600])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/out_3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/out_3']],...
		'position',[1220,275,1240,295])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn1']],...
		'hide name',0,...
		'MATLAB Fcn','VectUnit(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn1']],...
		'position',[465,573,525,607])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace18']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace18']],...
		'hide name',0,...
		'mat-name','B',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace18']],...
		'position',[585,544,650,566])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace19']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace19']],...
		'hide name',0,...
		'mat-name','unitB',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace19']],...
		'position',[585,579,650,601])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/pqr inutiliss']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/pqr inutiliss']],...
		'position',[470,630,475,635])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Q(1)']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Q(1)']],...
		'position',[440,685,445,690])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn2']],...
		'hide name',0,...
		'MATLAB Fcn','VectUnit(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/MATLAB Fcn2']],...
		'position',[475,738,535,772])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/unitaire',13,'de la rotation Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/unitaire',13,'de la rotation Q']],...
		'position',[630,773,635,778])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace20']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace20']],...
		'hide name',0,...
		'mat-name','unitQ',...
		'buffer','points_trace')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace20']],...
		'position',[585,740,640,770])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[670,595,700,755])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant3']],...
		'Value','angle_Bc_B',...
		'position',[705,690,785,720])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux6']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux6']],...
		'outputs','[3 3 1 3]',...
		'position',[365,561,415,784])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain']],...
		'hide name',0,...
		'position',[610,222,635,248])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain2']],...
		'hide name',0,...
		'position',[655,142,680,168])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace7']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace7']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','M1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace7']],...
		'buffer','points_trace',...
		'position',[615,104,650,126])

add_block('built-in/Demux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux3']],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'outputs','[3 1]')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Demux3']],...
		'position',[925,202,965,278])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace8']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace8']],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','M2')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To Workspace8']],...
		'buffer','points_trace',...
		'position',[605,279,640,301])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux']],...
		'hide name',0,...
		'inputs','[3 3 3 3]',...
		'position',[530,61,565,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique',13,'en colonne']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique',13,'en colonne']],...
		'MATLAB Fcn','laur0(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique',13,'en colonne']],...
		'position',[580,138,640,172])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum2']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Sum2']],...
		'hide name',0,...
		'position',[700,115,730,275])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Mux1']],...
		'hide name',0,...
		'inputs','[3 1]',...
		'position',[750,148,785,332])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']],...
		'ForeGround',1)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']],...
		'BackGround',2)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']],...
		'MATLAB Fcn','mom_prop(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']],...
		'Output Width','4')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue',13,'plafonns']],...
		'position',[855,223,915,257])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain3']],...
		'Gain','K_avant_saturation',...
		'position',[810,227,835,253])

add_block('built-in/Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Fcn']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Fcn']],...
		'Expr','(u(1)^2+u(2)^2+u(3)^2)^0.5',...
		'position',[730,665,770,685])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator']],...
		'Operator','<=',...
		'position',[895,660,945,720])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant4']],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Constant4']],...
		'Value','2-angle_Bc_B^2',...
		'position',[700,782,850,808])

add_block('built-in/Relational Operator',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator1']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator1']],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Relational',13,'Operator1']],...
		'position',[880,750,930,810])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/SATELLITE A L''ENVERS']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/SATELLITE A L''ENVERS']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/SATELLITE A L''ENVERS']],...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/SATELLITE A L''ENVERS']],...
		'position',[865,815,870,820])

add_block('built-in/Stop Simulation',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite bien cal']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite bien cal']],...
		'ForeGround',1,...
		'BackGround',0)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite bien cal']],...
		'position',[1045,650,1120,730])

add_block('built-in/Stop Simulation',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite retourn']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite retourn']],...
		'ForeGround',1,...
		'BackGround',3)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Stop Simulation',13,'satellite retourn']],...
		'position',[1150,740,1225,820])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B+pqr+Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/B+pqr+Q']],...
		'position',[285,340,290,345])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue']],...
		'ForeGround',1,...
		'BackGround',2)
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue']],...
		'MATLAB Fcn','laurens3(u)')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue']],...
		'Output Width','6')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Moment magntique ',13,'et',13,'couple roue']],...
		'position',[355,343,415,377])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain4']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain4']],...
		'hide name',0,...
		'Gain','K_LAURENS_SEULE')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/Gain4']],...
		'position',[445,347,470,373])

add_block('built-in/To File',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To File']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To File']],...
		'orientation',2,...
		'File name','moment1.mat',...
		'Matrix name','moment_1')
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS/To File']],...
		'position',[815,57,940,93])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[510,220;500,260])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[405,205;435,205;435,175;525,175])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[405,205;405,290;430,290])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[230,110;490,110;490,130;525,130])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[255,110;255,185;275,185])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[435,205;435,220;455,220])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[510,220;525,220])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[570,155;575,155])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[230,85;525,85])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[35,110;80,110])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[35,110;35,225;275,225])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[545,375;600,375])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[735,195;745,195])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[920,240;920,240])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[230,135;240,135;240,425;995,425;995,265;1015,265])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[970,220;1015,220])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1050,245;1065,245])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1135,245;1145,245])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1185,285;1215,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1030,470;1050,470])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1025,540;1050,540])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1090,505;1120,505;1120,325;1145,325])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[640,235;695,235])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[545,340;585,340;585,235;605,235])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[650,375;675,375])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1185,285;1195,285;1195,145;1160,145])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[970,220;970,75;1005,75])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1055,50;1110,50])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1055,75;1110,75])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[1055,100;1110,100])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[970,260;975,260;975,640;1045,640])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[975,590;1205,590])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[710,375;790,375])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[975,505;1050,505])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[730,375;730,285;745,285])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[320,205;320,360;350,360])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[430,85;420,45])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[325,360;325,475;410,475])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[35,220;35,515;410,515])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[530,590;580,590])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[540,755;580,755])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[330,475;330,675;360,675])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[420,590;460,590])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[435,590;435,555;580,555])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[420,755;470,755])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[545,590;545,635;665,635])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[560,755;560,715;665,715])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[705,675;725,675])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[775,675;890,675])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[790,705;890,705])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[950,690;1040,690])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[685,155;695,155])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[645,155;650,155])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[685,155;685,115;655,115])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[655,235;645,290])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[790,240;805,240])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[840,240;850,240])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[810,675;810,765;875,765])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[855,795;875,795])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[935,780;1145,780])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[475,360;495,360])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[420,360;440,360])
add_line([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],[970,75;945,75])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],...
		'Mask Display','CALCUL DES MOMENTS\n\nMAGNETIQUES\n\nET COUPLE ROUE')


%     Finished composite block ['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS'].

set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Moment magntique et',13,'couple roue en ',13,'rgulation de LAURENS']],...
		'position',[505,199,720,301])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Couple total magntique + roue',13,'de la rgulation de Laurens amliore']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Couple total magntique + roue',13,'de la rgulation de Laurens amliore']],...
		'position',[900,200,905,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Vecteur d''tat']])
set_param([sys,'/',['F(X,t) pour la rotation/Calcul des commandes, moments et roue/Vecteur d''tat']],...
		'position',[375,235,380,240])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/Couple roue uniaxial'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/Couple roue uniaxial'],...
		'position',[860,260,865,265])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/out_7'])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue/out_7'],...
		'hide name',0,...
		'Port','2',...
		'position',[760,265,780,285])
add_line([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],[455,250;500,250])
add_line([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],[725,225;745,225])
add_line([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],[725,275;755,275])
set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],...
		'Mask Display','REGULATION BOUSSOLE\n\nTECHNIQUE LAURENS\n\nPULSEE TYPE 2')


%     Finished composite block 'F(X,t) pour la rotation/Calcul des commandes, moments et roue'.

set_param([sys,'/','F(X,t) pour la rotation/Calcul des commandes, moments et roue'],...
		'position',[205,171,435,249])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Dcalage',13,'angulaire',13,'R//R0']])
set_param([sys,'/',['F(X,t) pour la rotation/Dcalage',13,'angulaire',13,'R//R0']],...
		'MATLAB Fcn','decalRR0(u)',...
		'Output Width','1',...
		'position',[325,408,385,442])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace6'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace6'],...
		'hide name',0,...
		'mat-name','angle_rot_R0_to_R',...
		'buffer','points_trace',...
		'position',[425,411,545,439])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Q'])
set_param([sys,'/','F(X,t) pour la rotation/Q'],...
		'position',[280,445,285,450])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace4'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','points_trace',...
		'position',[470,450,535,480])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Couple roue unidimensionnel sur tangage'])
set_param([sys,'/','F(X,t) pour la rotation/Couple roue unidimensionnel sur tangage'],...
		'position',[705,435,710,440])


%     Subsystem  'F(X,t) pour la rotation/Subsystem'.

new_system([sys,'/','F(X,t) pour la rotation/Subsystem'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],'Location',[4,50,970,451])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'ForeGround',2,...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','F(X,t) pour la rotation/Subsystem/Gain3'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/Gain3'],...
		'ForeGround',2,...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace5'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace5'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'ForeGround',2,...
		'position',[520,210,525,215])

add_block('built-in/Inport',[sys,'/','F(X,t) pour la rotation/Subsystem/in_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/in_1'],...
		'ForeGround',2,...
		'position',[20,125,40,145])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Subsystem/Inertie',13,'de la ',13,'roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Inertie',13,'de la ',13,'roue']],...
		'ForeGround',2,...
		'BackGround',7,...
		'Gain','1/J_ROUE',...
		'position',[195,115,230,155])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Subsystem/SUIVI DE LA ROUE'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/SUIVI DE LA ROUE'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[390,10,395,15])

add_block('built-in/Integrator',[sys,'/','F(X,t) pour la rotation/Subsystem/Integrator2'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/Integrator2'],...
		'ForeGround',2,...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[280,113,325,157])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace6'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace6'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace')
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To Workspace6'],...
		'position',[445,179,590,211])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/Subsystem/out_1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/out_1'],...
		'hide name',0,...
		'position',[610,330,630,350])

add_block('built-in/To File',[sys,'/','F(X,t) pour la rotation/Subsystem/To File'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To File'],...
		'ForeGround',2,...
		'BackGround',7,...
		'File name','vit_roue.mat',...
		'Matrix name','vit_roue_rd_s',...
		'position',[455,247,570,273])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Sortie de la vitesse ',13,'de la roue']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Sortie de la vitesse ',13,'de la roue']],...
		'position',[485,320,490,325])

add_block('built-in/To File',[sys,'/','F(X,t) pour la rotation/Subsystem/To File1'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To File1'],...
		'ForeGround',2,...
		'BackGround',7,...
		'File name','v_roue1.mat',...
		'Matrix name','vit_roue1',...
		'position',[615,67,730,93])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['F(X,t) pour la rotation/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'ForeGround',2,...
		'position',[415,70,420,75])

add_block('built-in/To File',[sys,'/','F(X,t) pour la rotation/Subsystem/To File2'])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem/To File2'],...
		'File name','cplroue1.mat',...
		'Matrix name','cplroue_1',...
		'position',[100,217,225,253])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[475,135;510,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[150,135;190,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[45,135;110,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[235,135;275,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[330,135;440,135])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[395,135;395,195;440,195])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[395,195;395,340;605,340])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[420,195;420,260;450,260])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[475,135;480,80;610,80])
add_line([sys,'/','F(X,t) pour la rotation/Subsystem'],[65,135;65,235;95,235])
set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'F(X,t) pour la rotation/Subsystem'.

set_param([sys,'/','F(X,t) pour la rotation/Subsystem'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[650,474,795,536])

add_block('built-in/Outport',[sys,'/','F(X,t) pour la rotation/out_2'])
set_param([sys,'/','F(X,t) pour la rotation/out_2'],...
		'Port','2',...
		'position',[1080,495,1100,515])

add_block('built-in/MATLAB Fcn',[sys,'/','F(X,t) pour la rotation/MATLAB Fcn1'])
set_param([sys,'/','F(X,t) pour la rotation/MATLAB Fcn1'],...
		'hide name',0,...
		'MATLAB Fcn','VectUnit(u)',...
		'Output Width','3',...
		'position',[400,518,460,552])

add_block('built-in/Note',[sys,'/','F(X,t) pour la rotation/Sortie vitesse roue'])
set_param([sys,'/','F(X,t) pour la rotation/Sortie vitesse roue'],...
		'position',[985,515,990,520])

add_block('built-in/To Workspace',[sys,'/','F(X,t) pour la rotation/To Workspace7'])
set_param([sys,'/','F(X,t) pour la rotation/To Workspace7'],...
		'hide name',0,...
		'mat-name','unitQ',...
		'buffer','points_trace',...
		'position',[495,520,550,550])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/unitaire',13,'de la rotation Q']])
set_param([sys,'/',['F(X,t) pour la rotation/unitaire',13,'de la rotation Q']],...
		'position',[515,555,520,560])

add_block('built-in/Demux',[sys,'/','F(X,t) pour la rotation/Demux1'])
set_param([sys,'/','F(X,t) pour la rotation/Demux1'],...
		'outputs','[1 3]',...
		'position',[325,511,365,544])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],'Location',[4,176,1271,782])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/To File',[sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To File']])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1/To File']],...
		'File name','cplpert1.mat',...
		'Matrix name','cplpert_1',...
		'position',[1160,386,1240,414])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],[1145,310;1155,400])
set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['F(X,t) pour la rotation/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[265,282,395,338])
add_line([sys,'/','F(X,t) pour la rotation'],[400,310;455,310])
add_line([sys,'/','F(X,t) pour la rotation'],[280,405;605,405])
add_line([sys,'/','F(X,t) pour la rotation'],[280,465;465,465])
add_line([sys,'/','F(X,t) pour la rotation'],[1015,335;1065,335])
add_line([sys,'/','F(X,t) pour la rotation'],[1100,335;1120,335])
add_line([sys,'/','F(X,t) pour la rotation'],[100,310;260,310])
add_line([sys,'/','F(X,t) pour la rotation'],[190,310;190,435;220,435])
add_line([sys,'/','F(X,t) pour la rotation'],[190,310;200,210])
add_line([sys,'/','F(X,t) pour la rotation'],[505,310;675,310])
add_line([sys,'/','F(X,t) pour la rotation'],[725,250;740,265])
add_line([sys,'/','F(X,t) pour la rotation'],[850,265;880,265])
add_line([sys,'/','F(X,t) pour la rotation'],[930,265;965,265])
add_line([sys,'/','F(X,t) pour la rotation'],[740,405;965,405])
add_line([sys,'/','F(X,t) pour la rotation'],[535,190;555,190])
add_line([sys,'/','F(X,t) pour la rotation'],[650,190;675,190])
add_line([sys,'/','F(X,t) pour la rotation'],[440,230;580,230;580,505;645,505])
add_line([sys,'/','F(X,t) pour la rotation'],[800,505;1075,505])
add_line([sys,'/','F(X,t) pour la rotation'],[440,190;480,190])
add_line([sys,'/','F(X,t) pour la rotation'],[295,465;295,425;320,425])
add_line([sys,'/','F(X,t) pour la rotation'],[390,425;420,425])
add_line([sys,'/','F(X,t) pour la rotation'],[295,465;295,530;320,530])
add_line([sys,'/','F(X,t) pour la rotation'],[370,535;395,535])
add_line([sys,'/','F(X,t) pour la rotation'],[465,535;490,535])
set_param([sys,'/','F(X,t) pour la rotation'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'F(X,t) pour la rotation'.

set_param([sys,'/','F(X,t) pour la rotation'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[135,248,360,332])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[510,203,555,552])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[445,205,450,210])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[435,465,440,470])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[430,250,455,325])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','etat_init',...
		'position',[630,354,730,406])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,44,1268,968])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])


%     Subsystem  ['Subsystem/Vitesses angulaires',13,'rd//s'].

new_system([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],[90,65;125,65])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Entries','5000\/-0.2\/0.2\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Subsystem/Vitesses angulaires',13,'rd//s'].

set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[365,192,475,228])


%     Subsystem  'Subsystem/Angles en degrs'.

new_system([sys,'/','Subsystem/Angles en degrs'])
set_param([sys,'/','Subsystem/Angles en degrs'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Subsystem/Angles en degrs/x'])
set_param([sys,'/','Subsystem/Angles en degrs/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Subsystem/Angles en degrs'],[90,65;125,65])
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Entries','5000\/-200\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Subsystem/Angles en degrs'.

set_param([sys,'/','Subsystem/Angles en degrs'],...
		'orientation',2,...
		'BackGround',2,...
		'position',[705,522,815,558])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[290,415,310,435])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[590,361,670,399])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[695,370,765,390])

add_block('built-in/To File',[sys,'/','Subsystem/To File4'])
set_param([sys,'/','Subsystem/To File4'],...
		'hide name',0,...
		'File name','angles1.mat',...
		'Matrix name','angles_1',...
		'position',[920,332,1010,378])

add_block('built-in/To File',[sys,'/','Subsystem/To File5'])
set_param([sys,'/','Subsystem/To File5'],...
		'hide name',0,...
		'File name','vitesse1.mat',...
		'Matrix name','vitesse_1',...
		'position',[1020,122,1110,168])

add_block('built-in/Gain',[sys,'/','Subsystem/Gain'])
set_param([sys,'/','Subsystem/Gain'],...
		'Gain','2',...
		'position',[1065,567,1090,593])

add_block('built-in/To File',[sys,'/','Subsystem/To File6'])
set_param([sys,'/','Subsystem/To File6'],...
		'hide name',0,...
		'File name','crit1.mat',...
		'Matrix name','crit_1',...
		'position',[1135,557,1225,603])

add_block('built-in/Constant',[sys,'/','Subsystem/Constant1'])
set_param([sys,'/','Subsystem/Constant1'],...
		'Value','instant_injection',...
		'position',[795,574,935,606])

add_block('built-in/Relational Operator',[sys,'/',['Subsystem/Relational',13,'Operator1']])
set_param([sys,'/',['Subsystem/Relational',13,'Operator1']],...
		'position',[980,551,1025,604])
add_line([sys,'/','Subsystem'],[525,380;585,380])
add_line([sys,'/','Subsystem'],[675,380;690,380])
add_line([sys,'/','Subsystem'],[315,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[550,210;480,210])
add_line([sys,'/','Subsystem'],[840,465;840,540;820,540])
add_line([sys,'/','Subsystem'],[840,465;840,355;915,355])
add_line([sys,'/','Subsystem'],[550,210;550,145;1015,145])
add_line([sys,'/','Subsystem'],[940,590;975,590])
add_line([sys,'/','Subsystem'],[1030,580;1060,580])
add_line([sys,'/','Subsystem'],[1095,580;1130,580])
add_line([sys,'/','Subsystem'],[945,535;945,565;975,565])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[850,230,1080,310])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[795,285,800,290])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[795,220,800,225])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[605,498,1207,791])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'Gain','0',...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[630,223,715,277])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[183,202,1170,587])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[15,105,35,125])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux1'])
set_param([sys,'/','Subsystem3/Mux1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[370,100,395,160])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'outputs','[3 3]',...
		'position',[265,96,305,129])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn'])
set_param([sys,'/','Subsystem3/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[175,98,235,132])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[305,158,340,192])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace3'])
set_param([sys,'/','Subsystem3/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_GP',...
		'buffer','1',...
		'position',[655,213,755,237])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace2'])
set_param([sys,'/','Subsystem3/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','initpqrQ_GP',...
		'buffer','1',...
		'position',[660,316,775,344])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','init_GP.mat',...
		'Matrix name','init_acqGP',...
		'position',[640,247,780,283])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[1 7]',...
		'position',[525,226,590,299])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace'])
set_param([sys,'/','Subsystem3/To Workspace'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','init_tmc_fin',...
		'buffer','1',...
		'position',[450,118,550,142])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace1'])
set_param([sys,'/','Subsystem3/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_tmcfin',...
		'buffer','1',...
		'position',[450,163,555,187])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux2'])
set_param([sys,'/','Subsystem3/Mux2'],...
		'inputs','[6 1]',...
		'position',[610,66,650,179])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','init_fin.mat',...
		'Matrix name','init_mod_fin',...
		'position',[675,107,815,143])

add_block('built-in/Note',[sys,'/','Subsystem3/Sorties pour mode fin'])
set_param([sys,'/','Subsystem3/Sorties pour mode fin'],...
		'position',[890,110,895,115])

add_block('built-in/Note',[sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']])
set_param([sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']],...
		'position',[870,240,875,245])

add_block('built-in/Note',[sys,'/','Subsystem3/Transmission des valeurs finales'])
set_param([sys,'/','Subsystem3/Transmission des valeurs finales'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[450,15,455,20])
add_line([sys,'/','Subsystem3'],[345,175;445,175])
add_line([sys,'/','Subsystem3'],[400,130;445,130])
add_line([sys,'/','Subsystem3'],[310,120;325,120;325,115;365,115])
add_line([sys,'/','Subsystem3'],[310,105;340,105;340,145;365,145])
add_line([sys,'/','Subsystem3'],[240,115;260,115])
add_line([sys,'/','Subsystem3'],[40,115;170,115])
add_line([sys,'/','Subsystem3'],[365,175;365,245;520,245])
add_line([sys,'/','Subsystem3'],[595,265;635,265])
add_line([sys,'/','Subsystem3'],[110,115;110,330;655,330])
add_line([sys,'/','Subsystem3'],[300,330;300,280;520,280])
add_line([sys,'/','Subsystem3'],[365,225;650,225])
add_line([sys,'/','Subsystem3'],[420,175;420,150;605,150])
add_line([sys,'/','Subsystem3'],[425,130;425,95;605,95])
add_line([sys,'/','Subsystem3'],[655,125;670,125])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIES DES CONDITIONS\nFINALES DEVANT SERVIR\nDE CONDITIONS INITIALES\nA LA FUTURE SIMULATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[845,337,1090,423])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[190,545,195,550])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[595,550,600,555])


%     Subsystem  'Couplage roue-satellite'.

new_system([sys,'/','Couplage roue-satellite'])
set_param([sys,'/','Couplage roue-satellite'],'Location',[90,50,975,400])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'])
set_param([sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'],...
		'ForeGround',3,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[530,50,535,55])

add_block('built-in/Mux',[sys,'/','Couplage roue-satellite/Mux'])
set_param([sys,'/','Couplage roue-satellite/Mux'],...
		'inputs','[1 7]',...
		'position',[285,108,340,252])

add_block('built-in/Outport',[sys,'/','Couplage roue-satellite/out_1'])
set_param([sys,'/','Couplage roue-satellite/out_1'],...
		'position',[680,170,700,190])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Vitesseroue'])
set_param([sys,'/','Couplage roue-satellite/Vitesseroue'],...
		'position',[190,105,195,110])

add_block('built-in/Note',[sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']])
set_param([sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']],...
		'position',[690,215,695,220])

add_block('built-in/MATLAB Fcn',[sys,'/','Couplage roue-satellite/magneto.m2'])
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue\nau second membre')
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'position',[390,156,530,204])

add_block('built-in/Gain',[sys,'/','Couplage roue-satellite/Gain1'])
set_param([sys,'/','Couplage roue-satellite/Gain1'],...
		'hide name',0,...
		'position',[595,167,620,193])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/pqrQ'])
set_param([sys,'/','Couplage roue-satellite/pqrQ'],...
		'position',[170,200,175,205])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_4'])
set_param([sys,'/','Couplage roue-satellite/in_4'],...
		'Port','2',...
		'position',[190,204,215,226])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_3'])
set_param([sys,'/','Couplage roue-satellite/in_3'],...
		'position',[185,135,205,155])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'])
set_param([sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'],...
		'position',[465,215,470,220])

add_block('built-in/To File',[sys,'/','Couplage roue-satellite/To File'])
set_param([sys,'/','Couplage roue-satellite/To File'],...
		'File name','untitled1.mat',...
		'position',[425,410,500,440])

add_block('built-in/To File',[sys,'/','Couplage roue-satellite/To File1'])
set_param([sys,'/','Couplage roue-satellite/To File1'],...
		'File name','couplag1.mat',...
		'Matrix name','couplage_1',...
		'position',[605,256,720,294])
add_line([sys,'/','Couplage roue-satellite'],[345,180;385,180])
add_line([sys,'/','Couplage roue-satellite'],[210,145;280,145])
add_line([sys,'/','Couplage roue-satellite'],[220,215;280,215])
add_line([sys,'/','Couplage roue-satellite'],[535,180;590,180])
add_line([sys,'/','Couplage roue-satellite'],[625,180;675,180])
add_line([sys,'/','Couplage roue-satellite'],[550,180;550,275;600,275])
set_param([sys,'/','Couplage roue-satellite'],...
		'Mask Display','COUPLAGE ROUE-SATELLITE')


%     Finished composite block 'Couplage roue-satellite'.

set_param([sys,'/','Couplage roue-satellite'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[130,350,345,405])


%     Subsystem  'Subsystem7'.

new_system([sys,'/','Subsystem7'])
set_param([sys,'/','Subsystem7'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem7/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem7/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem7/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem7/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem7/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem7/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem7/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem7/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem7/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem7/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem7/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem7/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem7/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem7/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem7/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem7/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem7/d) Lancer la simulation'])
set_param([sys,'/','Subsystem7/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem7/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem7/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem7/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem7/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem7/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem7/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem7/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem7/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem7/b) '])
set_param([sys,'/','Subsystem7/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem7/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem7/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem7/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem7/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem7/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem7/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem7/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem7/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem7/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem7'],...
		'Mask Display','OU',...
		'Mask Dialogue','eval(''K_LAURENS_SEULE=0,'')')


%     Finished composite block 'Subsystem7'.

set_param([sys,'/','Subsystem7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[940,615,1010,716])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance laurdat1.m, puls par dfaut',13,'']])
set_param([sys,'/',['L''initialisation',13,' lance laurdat1.m, puls par dfaut',13,'']],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[980,540,985,545])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','1\nINITIALISATION\npar double clic souris\nCAS GENERAL\n\npuis 2 ou 3',...
		'Mask Dialogue','eval(''laurdat1'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[855,425,1095,536])


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem5/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem5/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem5/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem5/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem5/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem5/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem5/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem5/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem5/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem5/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem5/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem5/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem5/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem5/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem5/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem5/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem5/d) Lancer la simulation'])
set_param([sys,'/','Subsystem5/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem5/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem5/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem5/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem5/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem5/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem5/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem5/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem5/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem5/b) '])
set_param([sys,'/','Subsystem5/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem5/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem5/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem5/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem5/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem5/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem5/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem5/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem5/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem5/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','2\n\nAVEC REGULATION\nROTATION\nTRANSVERSALE A B\n\n(Par dfaut)',...
		'Mask Dialogue','eval(''K_LAURENS_SEULE=1,'')')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[735,600,930,736])


%     Subsystem  'Subsystem6'.

new_system([sys,'/','Subsystem6'])
set_param([sys,'/','Subsystem6'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem6/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem6/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem6/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem6/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem6/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem6/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem6/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem6/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem6/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem6/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem6/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem6/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem6/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem6/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem6/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem6/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem6/d) Lancer la simulation'])
set_param([sys,'/','Subsystem6/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem6/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem6/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem6/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem6/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem6/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem6/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem6/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem6/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem6/b) '])
set_param([sys,'/','Subsystem6/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem6/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem6/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem6/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem6/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem6/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem6/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem6/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem6/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem6/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem6'],...
		'Mask Display','3\n\nSANS REGULATION\nROTATION\nTRANSVERSALE A B',...
		'Mask Dialogue','eval(''K_LAURENS_SEULE=0,'')')


%     Finished composite block 'Subsystem6'.

set_param([sys,'/','Subsystem6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1020,600,1230,736])

add_block('built-in/Note',[sys,'/',['Ci-dessous cliquer',13,'pour obtenir les tracs de courbes']])
set_param([sys,'/',['Ci-dessous cliquer',13,'pour obtenir les tracs de courbes']],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[380,580,385,585])


%     Subsystem  'Courbes'.

new_system([sys,'/','Courbes'])
set_param([sys,'/','Courbes'],'Location',[4,173,1234,1004])


%     Subsystem  'Courbes/Extras8'.

new_system([sys,'/','Courbes/Extras8'])
set_param([sys,'/','Courbes/Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_laurens2);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras8'.

set_param([sys,'/','Courbes/Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[575,155,750,221])


%     Subsystem  'Courbes/Extras9'.

new_system([sys,'/','Courbes/Extras9'])
set_param([sys,'/','Courbes/Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx,my,mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,my,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras9'.

set_param([sys,'/','Courbes/Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[330,75,555,136])


%     Subsystem  'Courbes/Extras19'.

new_system([sys,'/','Courbes/Extras19'])
set_param([sys,'/','Courbes/Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras19'],...
		'Mask Display','Champs magn drivs\nrel roulis\npuls constant roulis',...
		'Mask Dialogue','eval(''plot(temps,derb_reel_roulis,temps,derb_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras19'.

set_param([sys,'/','Courbes/Extras19'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[975,145,1175,211])


%     Subsystem  'Courbes/Extras17'.

new_system([sys,'/','Courbes/Extras17'])
set_param([sys,'/','Courbes/Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras17'],...
		'Mask Display','Champs magntiques\nrel roulis\npuls linaire roulis',...
		'Mask Dialogue','eval(''plot(temps,b_reel_roulis,temps,b_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras17'.

set_param([sys,'/','Courbes/Extras17'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[975,70,1175,136])


%     Subsystem  'Courbes/Extras16'.

new_system([sys,'/','Courbes/Extras16'])
set_param([sys,'/','Courbes/Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras16'],...
		'Mask Display','Voir la commande \navant le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras16'.

set_param([sys,'/','Courbes/Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[760,75,960,141])


%     Subsystem  'Courbes/Extras5'.

new_system([sys,'/','Courbes/Extras5'])
set_param([sys,'/','Courbes/Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras5'.

set_param([sys,'/','Courbes/Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[95,75,295,141])


%     Subsystem  'Courbes/Extras7'.

new_system([sys,'/','Courbes/Extras7'])
set_param([sys,'/','Courbes/Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras7'.

set_param([sys,'/','Courbes/Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[95,160,300,221])


%     Subsystem  'Courbes/Extras20'.

new_system([sys,'/','Courbes/Extras20'])
set_param([sys,'/','Courbes/Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras20'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant-com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras20'.

set_param([sys,'/','Courbes/Extras20'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[765,240,965,306])


%     Subsystem  'Courbes/Extras18'.

new_system([sys,'/','Courbes/Extras18'])
set_param([sys,'/','Courbes/Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras18'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras18'.

set_param([sys,'/','Courbes/Extras18'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[760,155,960,221])


%     Subsystem  'Courbes/Extras6'.

new_system([sys,'/','Courbes/Extras6'])
set_param([sys,'/','Courbes/Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras6'.

set_param([sys,'/','Courbes/Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[575,75,750,131])

add_block('built-in/Note',[sys,'/','Courbes/********************************************************************************************'])
set_param([sys,'/','Courbes/********************************************************************************************'],...
		'Font Name','Arial',...
		'Font Size',20,...
		'position',[670,345,675,350])

add_block('built-in/Note',[sys,'/','Courbes/COURBES PRINCIPALES'])
set_param([sys,'/','Courbes/COURBES PRINCIPALES'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[595,15,600,20])


%     Subsystem  'Courbes/Extras14'.

new_system([sys,'/','Courbes/Extras14'])
set_param([sys,'/','Courbes/Extras14'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras14'],...
		'Mask Display','Voir courbe\ndiffrence Bc - B ',...
		'Mask Dialogue','eval(''plot(temps,Bc-B);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras14'.

set_param([sys,'/','Courbes/Extras14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,450,275,516])


%     Subsystem  'Courbes/Extras15'.

new_system([sys,'/','Courbes/Extras15'])
set_param([sys,'/','Courbes/Extras15'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras15'],...
		'Mask Display','Voir courbe\ndiffrence B''c - B'' ',...
		'Mask Dialogue','eval(''plot(temps,Bc_prime-B_prime);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras15'.

set_param([sys,'/','Courbes/Extras15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,535,275,601])


%     Subsystem  'Courbes/Extras21'.

new_system([sys,'/','Courbes/Extras21'])
set_param([sys,'/','Courbes/Extras21'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras21'],...
		'Mask Display','Voir courbe\ncouple Laurens M1',...
		'Mask Dialogue','eval(''plot(temps,M1);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras21'.

set_param([sys,'/','Courbes/Extras21'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,450,530,516])


%     Subsystem  'Courbes/Extras23'.

new_system([sys,'/','Courbes/Extras23'])
set_param([sys,'/','Courbes/Extras23'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras23'],...
		'Mask Display','Voir courbe\ncouple total 1',...
		'Mask Dialogue','eval(''plot(temps,cpl_laurens2);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras23'.

set_param([sys,'/','Courbes/Extras23'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[600,450,775,516])


%     Subsystem  'Courbes/Extras24'.

new_system([sys,'/','Courbes/Extras24'])
set_param([sys,'/','Courbes/Extras24'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras24'],...
		'Mask Display','Voir courbe\ndcalage R / R0\nen degrs',...
		'Mask Dialogue','eval(''plot(temps,angle_rot_R0_to_R);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras24'.

set_param([sys,'/','Courbes/Extras24'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[605,545,780,611])


%     Subsystem  'Courbes/Extras12'.

new_system([sys,'/','Courbes/Extras12'])
set_param([sys,'/','Courbes/Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras12'],...
		'Mask Display','Voir courbe\ncouple commande\n roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_roue);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras12'.

set_param([sys,'/','Courbes/Extras12'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1025,430,1200,496])


%     Subsystem  'Courbes/Extras13'.

new_system([sys,'/','Courbes/Extras13'])
set_param([sys,'/','Courbes/Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras13'],...
		'Mask Display','Voir courbe\nvitesse de la\n roue (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras13'.

set_param([sys,'/','Courbes/Extras13'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1030,505,1195,566])


%     Subsystem  'Courbes/Extras10'.

new_system([sys,'/','Courbes/Extras10'])
set_param([sys,'/','Courbes/Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Courbes/Extras10'.

set_param([sys,'/','Courbes/Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[575,230,755,311])


%     Subsystem  'Courbes/Extras26'.

new_system([sys,'/','Courbes/Extras26'])
set_param([sys,'/','Courbes/Extras26'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras26'],...
		'Mask Display','Voir la vitesse angulaire\nde lacet seul (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,r,''''c.'''');grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras26'.

set_param([sys,'/','Courbes/Extras26'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[335,165,540,226])


%     Subsystem  'Courbes/Extras25'.

new_system([sys,'/','Courbes/Extras25'])
set_param([sys,'/','Courbes/Extras25'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras25'],...
		'Mask Display','Voir la vitesse angulaire\nde roulis seul (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,''''y.'''');grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras25'.

set_param([sys,'/','Courbes/Extras25'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[335,240,540,301])


%     Subsystem  'Courbes/Extras11'.

new_system([sys,'/','Courbes/Extras11'])
set_param([sys,'/','Courbes/Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras11'],...
		'Mask Display','Voir la vitesse angulaire\nde tangage seul (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,q,''''m.'''');grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras11'.

set_param([sys,'/','Courbes/Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[90,235,295,296])


%     Subsystem  'Courbes/Extras27'.

new_system([sys,'/','Courbes/Extras27'])
set_param([sys,'/','Courbes/Extras27'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras27'],...
		'Mask Display','Voir courbe\ndiffrence PB - B ',...
		'Mask Dialogue','eval(''plot(temps,PB_moins_B);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras27'.

set_param([sys,'/','Courbes/Extras27'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[100,620,275,686])


%     Subsystem  'Courbes/Extras28'.

new_system([sys,'/','Courbes/Extras28'])
set_param([sys,'/','Courbes/Extras28'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras28'],...
		'Mask Display','Voir courbe\nnorme de la\ndiffrence PB - B ',...
		'Mask Dialogue','eval(''plot(temps,norm_PB_moins_B);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras28'.

set_param([sys,'/','Courbes/Extras28'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,630,530,696])


%     Subsystem  'Courbes/Extras32'.

new_system([sys,'/','Courbes/Extras32'])
set_param([sys,'/','Courbes/Extras32'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras32'],...
		'Mask Display','Voir courbe\nquaternion(2:4)',...
		'Mask Dialogue','eval(''plot(temps,quater(1:length(quater),2:4));grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras32'.

set_param([sys,'/','Courbes/Extras32'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[830,450,1005,516])


%     Subsystem  'Courbes/Extras33'.

new_system([sys,'/','Courbes/Extras33'])
set_param([sys,'/','Courbes/Extras33'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras33'],...
		'Mask Display','Voir courbe\nquaternion(1)',...
		'Mask Dialogue','eval(''plot(temps,quater(1:length(quater),1));grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras33'.

set_param([sys,'/','Courbes/Extras33'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[830,535,1005,601])


%     Subsystem  'Courbes/Extras35'.

new_system([sys,'/','Courbes/Extras35'])
set_param([sys,'/','Courbes/Extras35'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras35'],...
		'Mask Display','Voir courbe\nunitaire(B)',...
		'Mask Dialogue','eval(''plot(temps,unitB);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras35'.

set_param([sys,'/','Courbes/Extras35'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[840,680,1120,741])


%     Subsystem  'Courbes/Extras36'.

new_system([sys,'/','Courbes/Extras36'])
set_param([sys,'/','Courbes/Extras36'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras36'],...
		'Mask Display','Voir courbe\nunitaire(Q)',...
		'Mask Dialogue','eval(''plot(temps,unitQ);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras36'.

set_param([sys,'/','Courbes/Extras36'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[840,615,1115,671])

add_block('built-in/Note',[sys,'/',['Courbes/Au cas o le satellite serait  l''envers']])
set_param([sys,'/',['Courbes/Au cas o le satellite serait  l''envers']],...
		'Font Name','Arial',...
		'Font Size',20,...
		'position',[315,775,320,780])


%     Subsystem  'Courbes/Extras30'.

new_system([sys,'/','Courbes/Extras30'])
set_param([sys,'/','Courbes/Extras30'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras30'],...
		'Mask Display','Voir courbe\nnorme de la\nsomme PB + B ',...
		'Mask Dialogue','eval(''plot(temps,norm_PB_plus_B);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras30'.

set_param([sys,'/','Courbes/Extras30'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[340,715,515,781])


%     Subsystem  'Courbes/Extras22'.

new_system([sys,'/','Courbes/Extras22'])
set_param([sys,'/','Courbes/Extras22'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras22'],...
		'Mask Display','Voir courbe\ncouple annexe M2',...
		'Mask Dialogue','eval(''plot(temps,M2);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras22'.

set_param([sys,'/','Courbes/Extras22'],...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,540,530,606])


%     Subsystem  'Courbes/Extras31'.

new_system([sys,'/','Courbes/Extras31'])
set_param([sys,'/','Courbes/Extras31'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras31'],...
		'Mask Display','Voir courbe\nsomme PB+B ',...
		'Mask Dialogue','eval(''plot(temps,PB_plus_B);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras31'.

set_param([sys,'/','Courbes/Extras31'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[105,715,280,781])

add_block('built-in/Note',[sys,'/','Courbes/COURBES ANNEXES ET MISE AU POINT'])
set_param([sys,'/','Courbes/COURBES ANNEXES ET MISE AU POINT'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[605,390,610,395])


%     Subsystem  'Courbes/Extras34'.

new_system([sys,'/','Courbes/Extras34'])
set_param([sys,'/','Courbes/Extras34'],'Location',[4,42,1012,678])
set_param([sys,'/','Courbes/Extras34'],...
		'Mask Display','Voir courbe\nunitaire(Q)- unitaire(B)',...
		'Mask Dialogue','eval(''plot(temps,unitQ-unitB);grid;figure(gcf)'')')


%     Finished composite block 'Courbes/Extras34'.

set_param([sys,'/','Courbes/Extras34'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[540,680,820,741])
set_param([sys,'/','Courbes'],...
		'Mask Display','SORTIES GRAPHIQUES\n\npremire phase')


%     Finished composite block 'Courbes'.

set_param([sys,'/','Courbes'],...
		'ForeGround',1,...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[860,745,1135,821])


%     Subsystem  'Subsystem8'.

new_system([sys,'/','Subsystem8'])
set_param([sys,'/','Subsystem8'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem8/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem8/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem8/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem8/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem8/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem8/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem8/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem8/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem8/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem8/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem8/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem8/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem8/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem8/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem8/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem8/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem8/d) Lancer la simulation'])
set_param([sys,'/','Subsystem8/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem8/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem8/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem8/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem8/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem8/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem8/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem8/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem8/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem8/b) '])
set_param([sys,'/','Subsystem8/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem8/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem8/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem8/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem8/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem8/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem8/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem8/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem8/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem8/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem8'],...
		'Mask Display','Puis pour terminer',...
		'Mask Dialogue','eval(''K_LAURENS_SEULE=0,'')')


%     Finished composite block 'Subsystem8'.

set_param([sys,'/','Subsystem8'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[280,665,510,691])

add_block('built-in/Note',[sys,'/',['DETUMBLING SEUL AVEC QUATERNION D''ATTITUDE ',13,'',13,'',13,'']])
set_param([sys,'/',['DETUMBLING SEUL AVEC QUATERNION D''ATTITUDE ',13,'',13,'',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',26,...
		'position',[640,5,645,10])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem4/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem4/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])

add_block('built-in/Note',[sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem4/b) '])
set_param([sys,'/','Subsystem4/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/','Subsystem4/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem4/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem4/d) Lancer la simulation'])
set_param([sys,'/','Subsystem4/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','LANCER L''ACQUISITION GROSSIERE\nregboux6.m\n (Rgulation PD de la rotation\n autour de l''axe de Q )',...
		'Mask Dialogue','eval(''regboux6'');')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[245,710,595,816])

add_block('built-in/Note',[sys,'/','Trasmission des valeurs finales pour la simulation regboux6.m, qui doit tre excute juste aprs'])
set_param([sys,'/','Trasmission des valeurs finales pour la simulation regboux6.m, qui doit tre excute juste aprs'],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16)
set_param([sys,'/','Trasmission des valeurs finales pour la simulation regboux6.m, qui doit tre excute juste aprs'],...
		'position',[635,155,640,160])
add_line(sys,[735,380;755,380;755,550;45,550;45,465;125,465])
add_line(sys,[560,380;625,380])
add_line(sys,[350,465;505,465])
add_line(sys,[755,380;755,250;845,250])
add_line(sys,[605,380;605,290;845,290])
add_line(sys,[45,465;45,290;130,290])
add_line(sys,[755,250;720,250])
add_line(sys,[755,380;840,380])
add_line(sys,[365,270;425,270])
add_line(sys,[350,380;410,380;410,305;425,305])
add_line(sys,[460,290;505,290])
add_line(sys,[45,390;125,390])
add_line(sys,[365,310;375,310;375,340;115,340;125,365])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
